@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/vcard.php,v 1.12.10.8 2009/01/06 15:27:39 jan Exp $
+ * $Horde: turba/vcard.php,v 1.12.10.9 2010/03/01 15:43:42 jan Exp $
  *
  * Copyright 2000-2009 The Horde Project (http://www.horde.org/)
  *
@@ -44,4 +44,4 @@ $filename = str_replace(' ', '_', $object->getValue('name'));
 if (!$filename) {
     $filename = _("contact");
 }
-$vcard->exportFile($filename . '.vcf', array($driver->tovCard($object)), NLS::getCharset());
+$vcard->exportFile($filename . '.vcf', array($driver->tovCard($object, '2.1', null, true)), NLS::getCharset());
